@@ -1,20 +1,19 @@
-/***************************************************************************
-    begin                : Sat Feb 16 2002
-    copyright            : (C) 2002 - 2004 by Scott Wheeler
-    email                : wheeler@kde.org
-
-    copyright            : (C) 2008 by Michael Pyne
-    email                : michael.pyne@kdemail.net
-***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/**
+ * Copyright (C) 2002-2004 Scott Wheeler <wheeler@kde.org>
+ * Copyright (C) 2008 Michael Pyne <mpyne@kde.org>
+ *
+ * This program is free software; you can redistribute it and/or modify it under
+ * the terms of the GNU General Public License as published by the Free Software
+ * Foundation; either version 2 of the License, or (at your option) any later
+ * version.
+ *
+ * This program is distributed in the hope that it will be useful, but WITHOUT ANY
+ * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
+ * PARTICULAR PURPOSE. See the GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License along with
+ * this program.  If not, see <http://www.gnu.org/licenses/>.
+ */
 
 #include "playlist.h"
 #include "juk-exception.h"
@@ -1046,8 +1045,9 @@ void Playlist::contentsDragEnterEvent(QDragEnterEvent *e)
     setDropHighlighter(false);
     setDropVisualizer(true);
 
-    KUrl::List urls;
-    if(!K3URLDrag::decode(e, urls) || urls.isEmpty()) {
+    const KUrl::List urls = KUrl::List::fromMimeData(e->mimeData());
+
+    if (urls.isEmpty()) {
         e->ignore();
         return;
     }
@@ -1058,7 +1058,7 @@ void Playlist::contentsDragEnterEvent(QDragEnterEvent *e)
 
 bool Playlist::acceptDrag(QDropEvent *e) const
 {
-    return CoverDrag::isCover(e->mimeData()) || K3URLDrag::canDecode(e);
+    return CoverDrag::isCover(e->mimeData()) || KUrl::List::canDecode(e->mimeData());
 }
 
 void Playlist::decode(const QMimeData *s, PlaylistItem *item)
@@ -2349,7 +2349,7 @@ void Playlist::slotCreateGroup()
 void Playlist::notifyUserColumnWidthModeChanged()
 {
     KMessageBox::information(this,
-                             i18n("Manual column widths have been enabled.  You can "
+                             i18n("Manual column widths have been enabled. You can "
                                   "switch back to automatic column sizes in the view "
                                   "menu."),
                              i18n("Manual Column Widths Enabled"),
